@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2012, 2021, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2012, 2023, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -1305,7 +1305,7 @@ public class TimeZoneNames_sv extends TimeZoneNamesBundle {
             { "Asia/Macau", China },
             { "Asia/Qatar", Arabian },
             { "Asia/Seoul", Korea },
-            { "Africa/Juba", Africa_Eastern },
+            { "Africa/Juba", Africa_Central },
             { "Africa/Lome", GMT },
             { "Asia/Almaty", Kazakhstan_Eastern },
             { "Asia/Anadyr", Anadyr },
@@ -1540,7 +1540,7 @@ public class TimeZoneNames_sv extends TimeZoneNamesBundle {
             { "America/Moncton", Atlantic },
             { "America/Nipigon", America_Eastern },
             { "America/Noronha", Noronha },
-            { "America/Ojinaga", America_Mountain },
+            { "America/Ojinaga", America_Central },
             { "America/Tijuana", America_Pacific },
             { "America/Toronto", America_Eastern },
             { "America/Tortola", Atlantic },
@@ -1626,7 +1626,7 @@ public class TimeZoneNames_sv extends TimeZoneNamesBundle {
             { "America/Araguaina", Brasilia },
             { "America/Boa_Vista", Amazon },
             { "America/Catamarca", Argentina },
-            { "America/Chihuahua", Mexico_Pacific },
+            { "America/Chihuahua", America_Central },
             { "America/Fortaleza", Brasilia },
             { "America/Glace_Bay", Atlantic },
             { "America/Goose_Bay", Atlantic },
@@ -1714,6 +1714,7 @@ public class TimeZoneNames_sv extends TimeZoneNamesBundle {
             { "Antarctica/Macquarie", Australia_Eastern },
             { "Pacific/Port_Moresby", Papua_New_Guinea },
             { "America/Cambridge_Bay", America_Mountain },
+            { "America/Ciudad_Juarez", America_Mountain },
             { "America/Coral_Harbour", America_Eastern },
             { "America/Indiana/Vevay", America_Eastern },
             { "America/Lower_Princes", Atlantic },
@@ -1884,7 +1885,6 @@ public class TimeZoneNames_sv extends TimeZoneNamesBundle {
             { "timezone.excity.Africa/Tripoli", "Tripoli" },
             { "timezone.excity.America/Belize", "Belize" },
             { "timezone.excity.America/Bogota", "Bogot\u00e1" },
-            { "timezone.excity.America/Cancun", "Canc\u00fan" },
             { "timezone.excity.America/Cayman", "Cayman\u00f6arna" },
             { "timezone.excity.America/Cuiaba", "Cuiab\u00e1" },
             { "timezone.excity.America/Dawson", "Dawson" },
@@ -1896,7 +1896,6 @@ public class TimeZoneNames_sv extends TimeZoneNamesBundle {
             { "timezone.excity.America/La_Paz", "La Paz" },
             { "timezone.excity.America/Maceio", "Macei\u00f3" },
             { "timezone.excity.America/Manaus", "Manaus" },
-            { "timezone.excity.America/Merida", "M\u00e9rida" },
             { "timezone.excity.America/Nassau", "Nassau" },
             { "timezone.excity.America/Panama", "Panama" },
             { "timezone.excity.America/Recife", "Recife" },
@@ -2140,7 +2139,6 @@ public class TimeZoneNames_sv extends TimeZoneNamesBundle {
             { "timezone.excity.America/St_Barthelemy", "S:t Barth\u00e9lemy" },
             { "timezone.excity.America/Swift_Current", "Swift Current" },
             { "timezone.excity.Australia/Broken_Hill", "Broken Hill" },
-            { "timezone.excity.America/Bahia_Banderas", "Bah\u00eda de Banderas" },
             { "timezone.excity.America/Port-au-Prince", "Port-au-Prince" },
             { "timezone.excity.Atlantic/South_Georgia", "Sydgeorgien" },
             { "timezone.excity.America/Argentina/Salta", "Salta" },
